pub struct HandlerType {
pub name: String,
pub signature: String,
}Expand description
Components used to construct the client type for this handler.
Fields
name: StringUnique name of the handler. This will automatically be namespaced as appropriate when the attached router is nested.
signature: StringSignature of this handler.